pub enum ToDeviceUnableToDecryptReason {
DecryptionFailure,
UnverifiedSenderDevice,
NoOlmMachine,
EncryptionIsDisabled,
}Expand description
Reason code for a to-device decryption failure
Variants
DecryptionFailure
An error occurred while encrypting the event. This covers all OlmError
types.
UnverifiedSenderDevice
We refused to decrypt the message because the sender’s device is not verified, or more generally, the sender’s identity did not match the trust requirement we were asked to provide.
NoOlmMachine
We have no OlmMachine. This should not happen unless we forget to set
things up by calling OlmMachine::activate().
EncryptionIsDisabled
The Matrix SDK was compiled without encryption support.